@@ -1,6 +1,8 @@
 import json
 import uuid
 import sys
+
+import dill
 import requests
 import pickle
 import pandas
@@ -9,6 +11,7 @@ import sklearn
 
 from .request import Request
 from .mlmodel import MLModel
+from .script import Script
 from .dataframe_toolkit import DataFrameToolkit
 from .dsapi_json_encoder import DSAPIEncoder
 
@@ -29,11 +32,15 @@ class WizataDSAPIClient:
     def __header(self):
         return {'Content-Type': 'application/json'}
 
-    def __request_process(self, method, route, content_json=None, return_type="json"):
+    def __request_process(self, method, route, content_json=None, return_type="json", args=None):
 
         # choosing the right request
         if content_json is None:
             response = requests.request(method, self.__url() + route, headers=self.__header())
+        elif method == "GET":
+            response = requests.request(method, self.__url() + route,
+                                        headers=self.__header(),
+                                        data=json.dumps(content_json, cls=DSAPIEncoder))
         else:
             response = requests.post(self.__url() + route,
                                      headers=self.__header(),
@@ -78,5 +85,18 @@ class WizataDSAPIClient:
         if isinstance(obj, MLModel):
             model_bytes = self.__request_process("POST", "get_model", {"model_id": str(obj.model_id)}, "pickle")
             return pickle.loads(model_bytes)
+        if isinstance(obj, Script):
+            script_bytes = self.__request_process("GET", "script", {"script_id": str(obj.script_id)}, "pickle")
+            return pickle.loads(script_bytes)
+        else:
+            raise TypeError("Type not supported.")
+
+    def upload(self, obj):
+        if isinstance(obj, Script):
+            response = requests.post(self.__url() + "script",
+                                     headers=self.__header(),
+                                     data=dill.dumps(obj.code),
+                                     params={"name": obj.name})
+            return response.json()["script_id"]
         else:
             raise TypeError("Type not supported.")
